@@ -291,7 +291,7 @@ crypto_hash_sha512_update(crypto_hash_sha512_state *state,
         src += 128;
         inlen -= 128;
     }
-    memcpy(state->buf, src, inlen);
+    memcpy(state->buf, src, inlen); /* inlen < 128 */
 
     return 0;
 }
