@@ -2,23 +2,28 @@
 #define TEST_NAME "box"
 #include "cmptest.h"
 
-static unsigned char alicesk[32]
+static const unsigned char alicesk[32]
     = { 0x77, 0x07, 0x6d, 0x0a, 0x73, 0x18, 0xa5, 0x7d, 0x3c, 0x16, 0xc1,
         0x72, 0x51, 0xb2, 0x66, 0x45, 0xdf, 0x4c, 0x2f, 0x87, 0xeb, 0xc0,
         0x99, 0x2a, 0xb1, 0x77, 0xfb, 0xa5, 0x1d, 0xb9, 0x2c, 0x2a };
 
-static unsigned char bobpk[32]
+static const unsigned char bobpk[32]
     = { 0xde, 0x9e, 0xdb, 0x7d, 0x7b, 0x7d, 0xc1, 0xb4, 0xd3, 0x5b, 0x61,
         0xc2, 0xec, 0xe4, 0x35, 0x37, 0x3f, 0x83, 0x43, 0xc8, 0x5b, 0x78,
         0x67, 0x4d, 0xad, 0xfc, 0x7e, 0x14, 0x6f, 0x88, 0x2b, 0x4f };
 
-static unsigned char nonce[24]
+static const unsigned char small_order_p[crypto_box_PUBLICKEYBYTES]
+    = { 0xe0, 0xeb, 0x7a, 0x7c, 0x3b, 0x41, 0xb8, 0xae, 0x16, 0x56, 0xe3,
+        0xfa, 0xf1, 0x9f, 0xc4, 0x6a, 0xda, 0x09, 0x8d, 0xeb, 0x9c, 0x32,
+        0xb1, 0xfd, 0x86, 0x62, 0x05, 0x16, 0x5f, 0x49, 0xb8, 0x00 };
+
+static const unsigned char nonce[24]
     = { 0x69, 0x69, 0x6e, 0xe9, 0x55, 0xb6, 0x2b, 0x73,
         0xcd, 0x62, 0xbd, 0xa8, 0x75, 0xfc, 0x73, 0xd6,
         0x82, 0x19, 0xe0, 0x03, 0x6b, 0x7a, 0x0b, 0x37 };
 
 // API requires first 32 bytes to be 0
-static unsigned char m[163]
+static const unsigned char m[163]
     = { 0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
         0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
         0,    0,    0,    0,    0,    0,    0,    0,    0xbe, 0x07, 0x5f, 0xc5,
@@ -50,8 +55,12 @@ int main(void)
             printf("\n");
     }
     printf("\n");
+    
+    ret = crypto_box(c, m, 163, nonce, small_order_p, alicesk);
+    assert(ret == -1);
 
     memset(c, 0, sizeof c);
+    
     ret = crypto_box_beforenm(k, bobpk, alicesk);
     assert(ret == 0);
     crypto_box_afternm(c, m, 163, nonce, k);
@@ -61,6 +70,9 @@ int main(void)
             printf("\n");
     }
     printf("\n");
+    
+    ret = crypto_box_beforenm(k, small_order_p, alicesk);
+    assert(ret == -1);
 
     assert(crypto_box_seedbytes() > 0U);
     assert(crypto_box_publickeybytes() > 0U);
