@@ -2,21 +2,22 @@
 #define TEST_NAME "box_easy"
 #include "cmptest.h"
 
-unsigned char alicesk[32]
+static unsigned char alicesk[32]
     = { 0x77, 0x07, 0x6d, 0x0a, 0x73, 0x18, 0xa5, 0x7d, 0x3c, 0x16, 0xc1,
         0x72, 0x51, 0xb2, 0x66, 0x45, 0xdf, 0x4c, 0x2f, 0x87, 0xeb, 0xc0,
         0x99, 0x2a, 0xb1, 0x77, 0xfb, 0xa5, 0x1d, 0xb9, 0x2c, 0x2a };
 
-unsigned char bobpk[32]
+static unsigned char bobpk[32]
     = { 0xde, 0x9e, 0xdb, 0x7d, 0x7b, 0x7d, 0xc1, 0xb4, 0xd3, 0x5b, 0x61,
         0xc2, 0xec, 0xe4, 0x35, 0x37, 0x3f, 0x83, 0x43, 0xc8, 0x5b, 0x78,
         0x67, 0x4d, 0xad, 0xfc, 0x7e, 0x14, 0x6f, 0x88, 0x2b, 0x4f };
 
-unsigned char nonce[24] = { 0x69, 0x69, 0x6e, 0xe9, 0x55, 0xb6, 0x2b, 0x73,
-                            0xcd, 0x62, 0xbd, 0xa8, 0x75, 0xfc, 0x73, 0xd6,
-                            0x82, 0x19, 0xe0, 0x03, 0x6b, 0x7a, 0x0b, 0x37 };
+static unsigned char nonce[24]
+    = { 0x69, 0x69, 0x6e, 0xe9, 0x55, 0xb6, 0x2b, 0x73,
+        0xcd, 0x62, 0xbd, 0xa8, 0x75, 0xfc, 0x73, 0xd6,
+        0x82, 0x19, 0xe0, 0x03, 0x6b, 0x7a, 0x0b, 0x37 };
 
-unsigned char m[131]
+static unsigned char m[131]
     = { 0xbe, 0x07, 0x5f, 0xc5, 0x3c, 0x81, 0xf2, 0xd5, 0xcf, 0x14, 0x13, 0x16,
         0xeb, 0xeb, 0x0c, 0x7b, 0x52, 0x28, 0xc5, 0x2a, 0x4c, 0x62, 0xcb, 0xd4,
         0x4b, 0x66, 0x84, 0x9b, 0x64, 0x24, 0x4f, 0xfc, 0xe5, 0xec, 0xba, 0xaf,
@@ -29,20 +30,40 @@ unsigned char m[131]
         0x60, 0x90, 0x2e, 0x52, 0xf0, 0xa0, 0x89, 0xbc, 0x76, 0x89, 0x70, 0x40,
         0xe0, 0x82, 0xf9, 0x37, 0x76, 0x38, 0x48, 0x64, 0x5e, 0x07, 0x05 };
 
-unsigned char c[147 + crypto_box_MACBYTES];
+static unsigned char c[147 + crypto_box_MACBYTES];
 
 int main(void)
 {
     size_t i;
+    int    ret;
 
-    crypto_box_easy(c, m, 131, nonce, bobpk, alicesk);
+    ret = crypto_box_easy(c, m, 131, nonce, bobpk, alicesk);
+    assert(ret == 0);
     for (i = 0; i < 131 + crypto_box_MACBYTES; ++i) {
         printf(",0x%02x", (unsigned int)c[i]);
-        if (i % 8 == 7)
-            printf("\n");
     }
     printf("\n");
 
+    /* Null message */
+
+    ret = crypto_box_easy(c, c, 0, nonce, bobpk, alicesk);
+    assert(ret == 0);
+    for (i = 0; i < 1 + crypto_box_MACBYTES; ++i) {
+        printf(",0x%02x", (unsigned int)c[i]);
+    }
+    printf("\n");
+    ret = crypto_box_open_easy(c, c, crypto_box_MACBYTES, nonce,
+                               bobpk, alicesk);
+    assert(ret == 0);
+    for (i = 0; i < 1 + crypto_box_MACBYTES; ++i) {
+        printf(",0x%02x", (unsigned int)c[i]);
+    }
+    printf("\n");
+    c[randombytes_uniform(crypto_box_MACBYTES)]++;
+    ret = crypto_box_open_easy(c, c, crypto_box_MACBYTES, nonce,
+                               bobpk, alicesk);
+    assert(ret == -1);
+
     assert(crypto_box_easy(c, m, SIZE_MAX - 1U, nonce, bobpk, alicesk) == -1);
 
     return 0;
