@@ -2,9 +2,9 @@
 #define TEST_NAME "hash"
 #include "cmptest.h"
 
-unsigned char x[] = "testing\n";
-unsigned char x2[] = "The Conscience of a Hacker is a small essay written January 8, 1986 by a computer security hacker who went by the handle of The Mentor, who belonged to the 2nd generation of Legion of Doom.";
-unsigned char h[crypto_hash_BYTES];
+static unsigned char x[] = "testing\n";
+static unsigned char x2[] = "The Conscience of a Hacker is a small essay written January 8, 1986 by a computer security hacker who went by the handle of The Mentor, who belonged to the 2nd generation of Legion of Doom.";
+static unsigned char h[crypto_hash_BYTES];
 
 int main(void)
 {
